@@ -21,17 +21,23 @@ testDf2 <- iris  # no rownames
 # factors cannot be expected to be maintained
 testDf2[["Species"]] <- as.character(testDf2[["Species"]])
 
+ndjson <- NULL
+#
+jsonlite::stream_out(
+  jsonlite::fromJSON(contacts),
+  con = textConnection("ndjson", open = "w", local = TRUE),
+  verbose = FALSE, auto_unbox = TRUE)
+#
 testDf3 <- data.frame(
-  json = strsplit(jsonify::to_ndjson(jsonify::from_json(contacts)), split = "\n")[[1]],
+  `json` = ndjson,
   stringsAsFactors = FALSE)
-
+#
 testDf4 <- data.frame(
   `_id` = uuid::UUIDgenerate(n = nrow(testDf3)),
-  `json` = strsplit(jsonify::to_ndjson(jsonify::from_json(contacts)), split = "\n")[[1]],
+  `json` = ndjson,
   stringsAsFactors = FALSE,
   check.names = FALSE)
 
-
 testJson <- contacts # has _id's
 testJson2 <- mapdata # no _id's
 
@@ -55,8 +61,6 @@ testFile2 <- function(..., env = parent.frame()) {
   testFile2
 }
 
-testUrl <- "http://httpbin.org/stream/98"
-
 
 
 #### helper for tests ####
